@@ -9,7 +9,7 @@ def main():
     try:
         flower = FlowerCommand()
         flower.execute_from_commandline()
-    except:
+    except Exception:
         import sys
         print(bugreport(app=flower.app), file=sys.stderr)
         raise
