@@ -26,16 +26,23 @@ try:
 except ImportError:
     from .utils.backports.collections import Counter
 
+from prometheus_client import Counter as PrometheusCounter, Histogram
 
 logger = logging.getLogger(__name__)
 
 
+class PrometheusMetrics(object):
+    events = PrometheusCounter('flower_events_total', "Number of events", ['worker', 'type', 'task'])
+    runtime = Histogram('flower_task_runtime_seconds', "Task runtime", ['worker', 'task'])
+
+
 class EventsState(State):
     # EventsState object is created and accessed only from ioloop thread
 
     def __init__(self, *args, **kwargs):
         super(EventsState, self).__init__(*args, **kwargs)
         self.counter = collections.defaultdict(Counter)
+        self.metrics = PrometheusMetrics()
 
     def event(self, event):
         worker_name = event['hostname']
@@ -43,6 +50,17 @@ class EventsState(State):
 
         self.counter[worker_name][event_type] += 1
 
+        if event_type.startswith('task-'):
+            task_id = event['uuid']
+            task_name = event.get('name', '')
+            if not task_name and task_id in self.tasks:
+                task_name = self.tasks[task_id].name or ''
+            self.metrics.events.labels(worker_name, event_type, task_name).inc()
+
+            runtime = event.get('runtime', 0)
+            if runtime:
+                self.metrics.runtime.labels(worker_name, task_name).observe(runtime)
+
         # Send event to api subscribers (via websockets)
         classname = api.events.getClassName(event_type)
         cls = getattr(api.events, classname, None)
@@ -111,6 +129,7 @@ class Events(threading.Thread):
                                          handlers={"*": self.on_event},
                                          app=self.capp)
                     try_interval = 1
+                    logger.debug("Capturing events...")
                     recv.capture(limit=None, timeout=None, wakeup=True)
 
             except (KeyboardInterrupt, SystemExit):
@@ -130,6 +149,7 @@ class Events(threading.Thread):
         # Periodically enable events for workers
         # launched after flower
         try:
+            logger.debug("Enabling events...")
             self.capp.control.enable_events()
         except Exception as e:
             logger.debug("Failed to enable events: '%s'", e)
