@@ -14,17 +14,16 @@ def gen_cookie_secret():
 def bugreport(app=None):
     try:
         import celery
-        from celery.app import set_default_app
         import tornado
-        import babel
+        import humanize
 
-        set_default_app(app)
+        app = app or celery.Celery()
 
-        return 'flower   -> flower:%s tornado:%s babel:%s%s' % (
+        return 'flower   -> flower:%s tornado:%s humanize:%s%s' % (
             __version__,
             tornado.version,
-            babel.__version__,
-            celery.bugreport()
+            humanize.VERSION,
+            app.bugreport()
         )
     except (ImportError, AttributeError):
         return 'Unknown Celery version'
@@ -36,3 +35,7 @@ def abs_path(path):
         cwd = os.environ.get('PWD') or os.getcwd()
         path = os.path.join(cwd, path)
     return path
+
+
+def prepend_url(url, prefix):
+    return '/' + prefix.strip('/') + url
